@@ -1,5 +1,5 @@
 /*
-    i801.c - Part of lm_sensors, Linux kernel modules for hardware
+    i2c-i801.c - Part of lm_sensors, Linux kernel modules for hardware
               monitoring
     Copyright (c) 1998 - 2002  Frodo Looijaard <frodol@dds.nl>,
     Philip Edelbrock <phil@netroedge.com>, and Mark D. Studebaker
@@ -22,16 +22,19 @@
 
 /*
     SUPPORTED DEVICES	PCI ID
-    82801AA		2413           
-    82801AB		2423           
-    82801BA		2443           
-    82801CA/CAM		2483           
+    82801AA		2413
+    82801AB		2423
+    82801BA		2443
+    82801CA/CAM		2483
     82801DB		24C3   (HW PEC supported, 32 byte buffer not supported)
     82801EB		24D3   (HW PEC supported, 32 byte buffer not supported)
     6300ESB		25A4   ("")
     ICH6		266A   ("")
     ICH7		27DA   ("")
     ESB2 		269B   ("")
+    ICH8		283E   ("")
+    ICH9		2930   ("")
+
     This driver supports several versions of Intel's I/O Controller Hubs (ICH).
     For SMBus support, they are similar to the PIIX4 and are part
     of Intel's '810' and other chipsets.
@@ -91,7 +94,21 @@
 #define PCI_DEVICE_ID_INTEL_ICH7_17	0x27da
 #endif
 
-#ifdef I2C_FUNC_SMBUS_BLOCK_DATA_PEC
+/* ICH8 is undefined */
+#ifndef PCI_DEVICE_ID_INTEL_ICH8_5
+#define PCI_DEVICE_ID_INTEL_ICH8_5	0x283e
+#endif
+
+/* ICH9 is undefined */
+#ifndef PCI_DEVICE_ID_INTEL_ICH9_6
+#define PCI_DEVICE_ID_INTEL_ICH9_6	0x2930
+#endif
+
+#ifndef PCI_DEVICE_ID_INTEL_TOLAPAI_1
+#define PCI_DEVICE_ID_INTEL_TOLAPAI_1	0x5032
+#endif
+
+#ifdef I2C_CLIENT_PEC
 #define HAVE_PEC
 #endif
 
@@ -144,37 +161,32 @@ MODULE_PARM_DESC(force_addr,
 		 "Forcibly enable the I801 at the given address. "
 		 "EXTREMELY DANGEROUS!");
 
-static int i801_transaction(void);
-static int i801_block_transaction(union i2c_smbus_data *data,
-				  char read_write, int command);
-
 static unsigned short i801_smba;
+static struct pci_driver i801_driver;
 static struct pci_dev *I801_dev;
 static int isich4;	/* is PEC supported? */
 static int isich5;	/* is i2c block read supported? */
 
-static int i801_setup(struct pci_dev *dev)
+static int __devinit i801_setup(struct pci_dev *dev)
 {
-	int error_return = 0;
 	unsigned char temp;
 
-	/* Note: we keep on searching until we have found 'function 3' */
-	if(PCI_FUNC(dev->devfn) != 3)
-		return -ENODEV;
-
 	I801_dev = dev;
 	if (dev->device == PCI_DEVICE_ID_INTEL_82801DB_3 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_82801EB_3 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_ESB_4 ||
-	    dev->device == PCI_DEVICE_ID_INTEL_ESB2_17 ||	
+	    dev->device == PCI_DEVICE_ID_INTEL_ESB2_17 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_ICH6_16 ||
-	    dev->device == PCI_DEVICE_ID_INTEL_ICH7_17)
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH7_17 ||
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH8_5 ||
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH9_6 ||
+	    dev->device == PCI_DEVICE_ID_INTEL_TOLAPAI_1)
 		isich4 = 1;
 	else
 		isich4 = 0;
 	isich5 = isich4 && dev->device != PCI_DEVICE_ID_INTEL_82801DB_3;
 
-	/* Determine the address of the SMBus areas */
+	/* Determine the address of the SMBus area */
 	if (force_addr) {
 		i801_smba = force_addr & 0xfff0;
 	} else {
@@ -187,11 +199,10 @@ static int i801_setup(struct pci_dev *dev)
 		}
 	}
 
-	if (!request_region(i801_smba, (isich4 ? 16 : 8), "i801-smbus")) {
+	if (!request_region(i801_smba, (isich4 ? 16 : 8), i801_driver.name)) {
 		dev_err(dev, "I801_smb region 0x%x already in use!\n",
 			i801_smba);
-		error_return = -EBUSY;
-		goto END;
+		return -EBUSY;
 	}
 
 	pci_read_config_byte(I801_dev, SMBHSTCFG, &temp);
@@ -201,17 +212,20 @@ static int i801_setup(struct pci_dev *dev)
 	/* If force_addr is set, we program the new address here. Just to make
 	   sure, we disable the device first. */
 	if (force_addr) {
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp & 0xfe);
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp & ~SMBHSTCFG_HST_EN);
 		pci_write_config_word(I801_dev, SMBBA, i801_smba);
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp | 0x01);
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp | SMBHSTCFG_HST_EN);
 		dev_warn(dev, "WARNING: I801 SMBus interface set to "
 			"new address %04x!\n", i801_smba);
-	} else if ((temp & 1) == 0) {
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp | 1);
+	} else if (!(temp & SMBHSTCFG_HST_EN)) {
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp | SMBHSTCFG_HST_EN);
 		dev_warn(dev, "enabling SMBus device\n");
 	}
 
-	if (temp & 0x02)
+	if (temp & SMBHSTCFG_SMB_SMI_EN)
 		dev_dbg(dev, "I801 using Interrupt SMI# for SMBus.\n");
 	else
 		dev_dbg(dev, "I801 using PCI Interrupt for SMBus.\n");
@@ -220,8 +234,7 @@ static int i801_setup(struct pci_dev *dev)
 	dev_dbg(dev, "SMBREV = 0x%X\n", temp);
 	dev_dbg(dev, "I801_smba = 0x%X\n", i801_smba);
 
-END:
-	return error_return;
+	return 0;
 }
 
 
@@ -246,7 +259,7 @@ static int i801_transaction(void)
 			dev_dbg(I801_dev, "Failed! (%02x)\n", temp);
 			return -1;
 		} else {
-			dev_dbg(I801_dev, "Successfull!\n");
+			dev_dbg(I801_dev, "Successful!\n");
 		}
 	}
 
@@ -297,7 +310,7 @@ static int i801_transaction(void)
 
 /* All-inclusive block transaction function */
 static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
-				  int command)
+				  int command, int hwpec)
 {
 	int i, len;
 	int smbcmd;
@@ -323,23 +336,19 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 		len = data->block[0];
 		if (len < 1)
 			len = 1;
-		if (len > 32)
-			len = 32;
+		if (len > I2C_SMBUS_BLOCK_MAX)
+			len = I2C_SMBUS_BLOCK_MAX;
 		outb_p(len, SMBHSTDAT0);
 		outb_p(data->block[1], SMBBLKDAT);
 	} else {
 		len = 32;	/* max for reads */
 	}
 
-	if(isich4 && command != I2C_SMBUS_I2C_BLOCK_DATA) {
-		/* set 32 byte buffer */
-	}
-
 	for (i = 1; i <= len; i++) {
 		if (i == len && read_write == I2C_SMBUS_READ)
 			smbcmd = I801_BLOCK_LAST;
 		else if (command == I2C_SMBUS_I2C_BLOCK_DATA &&
-		         read_write == I2C_SMBUS_READ)
+			 read_write == I2C_SMBUS_READ)
 			smbcmd = I801_I2C_BLOCK_DATA;
 		else
 			smbcmd = I801_BLOCK_DATA;
@@ -353,13 +362,13 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 		/* Make sure the SMBus host is ready to start transmitting */
 		temp = inb_p(SMBHSTSTS);
 		if (i == 1) {
-			/* Erronenous conditions before transaction: 
+			/* Erroneous conditions before transaction:
 			 * Byte_Done, Failed, Bus_Err, Dev_Err, Intr, Host_Busy */
-			errmask=0x9f; 
+			errmask = 0x9f;
 		} else {
-			/* Erronenous conditions during transaction: 
+			/* Erroneous conditions during transaction:
 			 * Failed, Bus_Err, Dev_Err, Intr */
-			errmask=0x1e; 
+			errmask = 0x1e;
 		}
 		if (temp & errmask) {
 			dev_dbg(I801_dev, "SMBus busy (%02x). "
@@ -369,7 +378,7 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 				dev_err(I801_dev,
 					"Reset failed! (%02x)\n", temp);
 				result = -1;
-                                goto END;
+				goto END;
 			}
 			if (i != 1) {
 				/* if die in middle of block transaction, fail */
@@ -384,11 +393,11 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 		/* We will always wait for a fraction of a second! */
 		timeout = 0;
 		do {
-			temp = inb_p(SMBHSTSTS);
 			i2c_delay(1);
+			temp = inb_p(SMBHSTSTS);
 		}
-		    while ((!(temp & 0x80))
-			   && (timeout++ < MAX_TIMEOUT));
+		while ((!(temp & 0x80))
+		       && (timeout++ < MAX_TIMEOUT));
 
 		/* If the SMBus is still busy, we give up */
 		if (timeout >= MAX_TIMEOUT) {
@@ -413,8 +422,8 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 				len = inb_p(SMBHSTDAT0);
 				if (len < 1)
 					len = 1;
-				if (len > 32)
-					len = 32;
+				if (len > I2C_SMBUS_BLOCK_MAX)
+					len = I2C_SMBUS_BLOCK_MAX;
 				data->block[0] = len;
 			} else {
 				/* if slave returns < 32 bytes transaction will fail */
@@ -444,22 +453,20 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 			goto END;
 	}
 
-#ifdef HAVE_PEC
-	if(isich4 && command == I2C_SMBUS_BLOCK_DATA_PEC) {
+	if (hwpec) {
 		/* wait for INTR bit as advised by Intel */
 		timeout = 0;
 		do {
-			temp = inb_p(SMBHSTSTS);
 			i2c_delay(1);
+			temp = inb_p(SMBHSTSTS);
 		} while ((!(temp & 0x02))
 			   && (timeout++ < MAX_TIMEOUT));
 
 		if (timeout >= MAX_TIMEOUT) {
 			dev_dbg(I801_dev, "PEC Timeout!\n");
 		}
-		outb_p(temp, SMBHSTSTS); 
+		outb_p(temp, SMBHSTSTS);
 	}
-#endif
 	result = 0;
 END:
 	if (command == I2C_SMBUS_I2C_BLOCK_DATA &&
@@ -480,8 +487,9 @@ static s32 i801_access(struct i2c_adapter * adap, u16 addr,
 	int ret, xact = 0;
 
 #ifdef HAVE_PEC
-	if(isich4)
-		hwpec = (flags & I2C_CLIENT_PEC) != 0;
+	hwpec = isich4 && (flags & I2C_CLIENT_PEC)
+		&& size != I2C_SMBUS_QUICK
+		&& size != I2C_SMBUS_I2C_BLOCK_DATA;
 #endif
 
 	switch (size) {
@@ -517,11 +525,6 @@ static s32 i801_access(struct i2c_adapter * adap, u16 addr,
 		break;
 	case I2C_SMBUS_BLOCK_DATA:
 	case I2C_SMBUS_I2C_BLOCK_DATA:
-#ifdef HAVE_PEC
-	case I2C_SMBUS_BLOCK_DATA_PEC:
-		if(hwpec && size == I2C_SMBUS_BLOCK_DATA)
-			size = I2C_SMBUS_BLOCK_DATA_PEC;
-#endif
 		outb_p(((addr & 0x7f) << 1) | (read_write & 0x01),
 		       SMBHSTADD);
 		outb_p(command, SMBHSTCMD);
@@ -533,27 +536,19 @@ static s32 i801_access(struct i2c_adapter * adap, u16 addr,
 		return -1;
 	}
 
-#ifdef HAVE_PEC
-	if(isich4 && hwpec) {
-		if(size != I2C_SMBUS_QUICK &&
-		   size != I2C_SMBUS_I2C_BLOCK_DATA)
-			outb_p(1, SMBAUXCTL);	/* enable HW PEC */
-	}
-#endif
+	outb_p(hwpec, SMBAUXCTL);	/* enable/disable hardware PEC */
+
 	if(block)
-		ret = i801_block_transaction(data, read_write, size);
+		ret = i801_block_transaction(data, read_write, size, hwpec);
 	else {
 		outb_p(xact | ENABLE_INT9, SMBHSTCNT);
 		ret = i801_transaction();
 	}
 
-#ifdef HAVE_PEC
-	if(isich4 && hwpec) {
-		if(size != I2C_SMBUS_QUICK &&
-		   size != I2C_SMBUS_I2C_BLOCK_DATA)
-			outb_p(0, SMBAUXCTL);
-	}
-#endif
+	/* Some BIOSes don't like it when PEC is enabled at reboot or resume
+	   time, so we forcibly disable it after every transaction. */
+	if (hwpec)
+		outb_p(0, SMBAUXCTL);
 
 	if(block)
 		return ret;
@@ -594,13 +589,11 @@ static u32 i801_func(struct i2c_adapter *adapter)
 	    I2C_FUNC_SMBUS_BYTE_DATA | I2C_FUNC_SMBUS_WORD_DATA |
 	    I2C_FUNC_SMBUS_BLOCK_DATA | I2C_FUNC_SMBUS_WRITE_I2C_BLOCK
 #ifdef HAVE_PEC
-	     | (isich4 ? I2C_FUNC_SMBUS_BLOCK_DATA_PEC |
-	                 I2C_FUNC_SMBUS_HWPEC_CALC
-	               : 0)
+	     | (isich4 ? I2C_FUNC_SMBUS_HWPEC_CALC : 0)
 #endif
 #if 0
 	     | (isich5 ? I2C_FUNC_SMBUS_READ_I2C_BLOCK
-	               : 0)
+		       : 0)
 #endif
 	    ;
 }
@@ -615,7 +608,6 @@ static struct i2c_algorithm smbus_algorithm = {
 static struct i2c_adapter i801_adapter = {
 	.id		= I2C_ALGO_SMBUS | I2C_HW_SMBUS_I801,
 	.algo		= &smbus_algorithm,
-	.name		= "unset",
 	.inc_use	= i801_inc,
 	.dec_use	= i801_dec,
 };
@@ -681,17 +673,33 @@ static struct pci_device_id i801_ids[] __devinitdata = {
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 	},
+	{
+		.vendor =	PCI_VENDOR_ID_INTEL,
+		.device =	PCI_DEVICE_ID_INTEL_ICH8_5,
+		.subvendor =	PCI_ANY_ID,
+		.subdevice =	PCI_ANY_ID,
+	},
+	{
+		.vendor =	PCI_VENDOR_ID_INTEL,
+		.device =	PCI_DEVICE_ID_INTEL_ICH9_6,
+		.subvendor =	PCI_ANY_ID,
+		.subdevice =	PCI_ANY_ID,
+	},
+	{
+		.vendor =	PCI_VENDOR_ID_INTEL,
+		.device =	PCI_DEVICE_ID_INTEL_TOLAPAI_1,
+		.subvendor =	PCI_ANY_ID,
+		.subdevice =	PCI_ANY_ID,
+	},
 	{ 0, }
 };
 
 static int __devinit i801_probe(struct pci_dev *dev, const struct pci_device_id *id)
 {
+	int err;
 
-	if (i801_setup(dev)) {
-		dev_warn(dev,
-			"I801 not detected, module not inserted.\n");
-		return -ENODEV;
-	}
+	if ((err = i801_setup(dev)))
+		return err;
 
 	snprintf(i801_adapter.name, 32,
 		"SMBus I801 adapter at %04x", i801_smba);
