@@ -37,15 +37,7 @@
 #define DEBUG 1
 */
 
-static unsigned short normal_i2c[] = { SENSORS_I2C_END };
-static unsigned short normal_i2c_range[] = { SENSORS_I2C_END };
-static unsigned int normal_isa[] = { SENSORS_ISA_END };
-static unsigned int normal_isa_range[] = { SENSORS_ISA_END };
-
-SENSORS_INSMOD_1(bmcsensors);
-
 struct bmcsensors_data {
-	struct semaphore lock;
 	int sysctl_id;
 
 	struct semaphore update_lock;
@@ -91,15 +83,11 @@ static struct i2c_driver bmcsensors_driver = {
 };
 
 static struct bmcsensors_data bmc_data;
-struct i2c_client bmc_client = {
-	"BMC Sensors",
-	1,                  /* fake should be 0 */
-	0,
-	0,
-	NULL,   /* adapter */
-	&bmcsensors_driver,
-	& bmc_data,
-	0
+static struct i2c_client bmc_client = {
+	.name		= "BMC Sensors",
+	.id		= 1,                  /* fake should be 0 */
+	.driver		= &bmcsensors_driver,
+	.data		= &bmc_data,
 };
 
 static int bmcsensors_initialized;
@@ -218,8 +206,10 @@ static void ipmi_sprintf(u8 * to, u8 * from, u8 type, u8 length)
 		case 2: 	/* packed ascii */ /* if not a mult. of 3 this will run over */     
 			for(i = 0; i < length; i += 3) {
 				*to++ = *from & 0x3f;
-				*to++ = *from++ >> 6 | ((*from & 0xf)  << 2);
-				*to++ = *from++ >> 4 | ((*from & 0x3)  << 4);
+				*to++ = *from >> 6 | ((*(from+1) & 0xf)  << 2);
+				from++;
+				*to++ = *from >> 4 | ((*(from+1) & 0x3)  << 4);
+				from++;
 				*to++ = (*from++ >> 2) & 0x3f;
 			}
 			*to = 0;
@@ -298,7 +288,7 @@ static void bmcsensors_select_thresholds(struct sdrdata * sd)
 	}
 
 	/* swap lim1/lim2 if m < 0 or function is 1/x (but not both!) */
-	if(sd->m < 0 && sd->linear != 7 || sd->m >= 0 && sd->linear == 7) {
+	if((sd->m < 0 && sd->linear != 7) || (sd->m >= 0 && sd->linear == 7)) {
 		tmp = sd->lim1;
 		sd->lim1 = sd->lim2;
 		sd->lim2 = tmp;
@@ -323,7 +313,7 @@ static void bmcsensors_select_thresholds(struct sdrdata * sd)
 /* After we have received all the SDR entries and picked out the ones
    we are interested in, build a table of the /proc entries and register with i2c.
 */
-static void bmcsensors_build_proc_table()
+static void bmcsensors_build_proc_table(void)
 {
 	int i;
 	int temps = 0, volts = 0, currs = 0, fans = 0;
@@ -506,7 +496,7 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 	}
 
 	nextrecord = (data[2] << 8) | data[1];
-	/* printk(KERN_INFO "bmcsensors.o: nextrecord %d \n", nextrecord); */
+	/* printk(KERN_INFO "bmcsensors.o: nextrecord %d\n", nextrecord); */
 
 
 	type = data[6];
@@ -889,7 +879,7 @@ static void bmcsensors_update_client(struct i2c_client *client)
 		if(state != STATE_READING) {
 			state = STATE_READING;
 #ifdef DEBUG
-			printk(KERN_DEBUG "bmcsensors.o: starting update\n", j);
+			printk(KERN_DEBUG "bmcsensors.o: starting update\n");
 #endif
 			bmcsensors_get_reading(client, 0);
 		}
@@ -897,7 +887,7 @@ static void bmcsensors_update_client(struct i2c_client *client)
 		while(state == STATE_READING && j++ < 100)
 			bmc_do_pause(HZ / 25);
 #ifdef DEBUG
-		printk("bmcsensors.o: update complete; j = %d\n", j);
+		printk(KERN_DEBUG "bmcsensors.o: update complete; j = %d\n", j);
 #endif
 		data->last_updated = jiffies;
 		data->valid = 1;
