@@ -165,6 +165,11 @@ SENSORS_INSMOD_6(lm85b, lm85c, adm1027, adt7463, emc6d100, emc6d102);
 #define EMC6D100_REG_IN_MIN(nr) (0x73 + ((nr)-5) * 2)
 #define EMC6D100_REG_IN_MAX(nr) (0x74 + ((nr)-5) * 2)
 
+#define EMC6D102_REG_EXTEND_ADC1 0x85
+#define EMC6D102_REG_EXTEND_ADC2 0x86
+#define EMC6D102_REG_EXTEND_ADC3 0x87
+#define EMC6D102_REG_EXTEND_ADC4 0x88
+
 /* Conversions. Rounding and limit checking is only done on the TO_REG 
    variants. Note that you should be a bit careful with which arguments
    these macros are called: arguments may be evaluated more than once.
@@ -186,7 +191,7 @@ static int lm85_scaling[] = {  /* .001 Volts */
 #define INS_FROM_REG(n,val) (INSEXT_FROM_REG(n,val,0))
 
 /* FAN speed is measured using 90kHz clock */
-#define FAN_TO_REG(val)  (SENSORS_LIMIT( (val)<=0?0: 5400000/(val),0,65534))
+#define FAN_TO_REG(val)  ((val)<=0?0xffff:SENSORS_LIMIT(5400000/(val),1,65534))
 #define FAN_FROM_REG(val) ((val)==0?-1:(val)==0xffff?0:5400000/(val))
 
 /* Temperature is reported in .01 degC increments */
@@ -373,7 +378,6 @@ struct lm85_autofan {
 
 struct lm85_data {
 	struct i2c_client client;
-	struct semaphore lock;
 	int sysctl_id;
 	enum chips type;
 
@@ -693,14 +697,14 @@ static ctl_table emc6d100_specific[] = {
      * lm85_driver is inserted (when this module is loaded), for each
        available adapter
      * when a new adapter is inserted (and lm85_driver is still present) */
-int lm85_attach_adapter(struct i2c_adapter *adapter)
+static int lm85_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, lm85_detect);
 }
 
 /* This function is called by i2c_detect */
-int lm85_detect(struct i2c_adapter *adapter, int address,
-		unsigned short flags, int kind)
+static int lm85_detect(struct i2c_adapter *adapter, int address,
+		       unsigned short flags, int kind)
 {
 	int i;
 	int company, verstep ;
@@ -864,7 +868,7 @@ int lm85_detect(struct i2c_adapter *adapter, int address,
 		template_used = 0;
 		break;
 	default :
-		printk("lm85: Internal error, invalid kind (%d)!", kind);
+		printk("lm85: Internal error, invalid kind (%d)!\n", kind);
 		err = -EFAULT ;
 		goto ERROR1;
 	}
@@ -889,6 +893,7 @@ int lm85_detect(struct i2c_adapter *adapter, int address,
 	data->therm_ovfl = 0;
 
 	init_MUTEX(&data->update_lock);
+	data->extend_adc = 0;
 
 	/* Initialize the LM85 chip */
 	lm85_init_client(new_client);
@@ -921,7 +926,7 @@ int lm85_detect(struct i2c_adapter *adapter, int address,
 	return err;
 }
 
-int lm85_detach_client(struct i2c_client *client)
+static int lm85_detach_client(struct i2c_client *client)
 {
 	int err;
 	int id ;
@@ -940,7 +945,7 @@ int lm85_detach_client(struct i2c_client *client)
 	return 0;
 }
 
-int lm85_read_value(struct i2c_client *client, u16 reg)
+static int lm85_read_value(struct i2c_client *client, u16 reg)
 {
 	int res;
 
@@ -974,7 +979,7 @@ int lm85_read_value(struct i2c_client *client, u16 reg)
 	return res ;
 }
 
-int lm85_write_value(struct i2c_client *client, u16 reg, int value)
+static int lm85_write_value(struct i2c_client *client, u16 reg, int value)
 {
 	int res ;
 
@@ -1006,8 +1011,8 @@ int lm85_write_value(struct i2c_client *client, u16 reg, int value)
 	return res ;
 }
 
-/* Called when we have found a new LM85. It should set limits, etc. */
-void lm85_init_client(struct i2c_client *client)
+/* Called when we have found a new LM85. */
+static void lm85_init_client(struct i2c_client *client)
 {
 	int value;
 	struct lm85_data *data = client->data;
@@ -1091,7 +1096,7 @@ void lm85_init_client(struct i2c_client *client)
 
 }
 
-void lm85_update_client(struct i2c_client *client)
+static void lm85_update_client(struct i2c_client *client)
 {
 	struct lm85_data *data = client->data;
 	int i;
@@ -1115,7 +1120,6 @@ void lm85_update_client(struct i2c_client *client)
 			    lm85_read_value(client, ADM1027_REG_EXTEND_ADC);
 			break ;
 		default :
-			data->extend_adc = 0 ;
 			break ;
 		}
 
@@ -1141,7 +1145,7 @@ void lm85_update_client(struct i2c_client *client)
 
 		data->alarms = lm85_read_value(client, LM85_REG_ALARM);
 
-		switch( ((struct lm85_data *)(client->data))->type ) {
+		switch( data->type ) {
 		case adt7463 :
 			/* REG_THERM code duplicated in therm_signal() */
 			i = lm85_read_value(client, ADT7463_REG_THERM);
@@ -1163,6 +1167,26 @@ void lm85_update_client(struct i2c_client *client)
 			    lm85_read_value(client, EMC6D100_REG_ALARM3) << 16;
 
 			break ;
+		case emc6d102 :
+			/* Have to read LSB bits after the MSB ones because
+			   the reading of the MSB bits has frozen the
+			   LSBs (backward from the ADM1027).
+			   We use only two extra bits per channel, and encode
+			   them in the same format the ADM1027 uses, to keep the
+			   rest of the code unchanged.
+			 */
+			i = lm85_read_value(client, EMC6D102_REG_EXTEND_ADC1);
+			data->extend_adc = (i & 0xcc) << 8; /* temp3, temp1 */
+			i = lm85_read_value(client, EMC6D102_REG_EXTEND_ADC2);
+			data->extend_adc |= (i & 0x0c) << 10; /* temp2 */
+			data->extend_adc |= (i & 0xc0) << 2; /* in4 */
+			i = lm85_read_value(client, EMC6D102_REG_EXTEND_ADC3);
+			data->extend_adc |= (i & 0x0c) >> 2; /* in0 */
+			data->extend_adc |= i & 0xc0; /* in3 */
+			i = lm85_read_value(client, EMC6D102_REG_EXTEND_ADC4);
+			data->extend_adc |= i & 0x0c; /* in1 */
+			data->extend_adc |= (i & 0xc0) >> 2; /* in2 */
+			break;
 		default : break ; /* no warnings */
 		}
 
@@ -1229,7 +1253,7 @@ void lm85_update_client(struct i2c_client *client)
 		i = lm85_read_value(client, LM85_REG_AFAN_HYST2);
 		data->zone[2].hyst = (i>>4) & 0x0f ;
 
-		switch( ((struct lm85_data *)(client->data))->type ) {
+		switch( data->type ) {
 		case lm85b :
 		case lm85c :
 			data->tach_mode = lm85_read_value(client,
@@ -1301,7 +1325,7 @@ void lm85_in(struct i2c_client *client, int operation, int ctl_name,
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 3;  /* 1.000 */
 	else if (operation == SENSORS_PROC_REAL_READ) {
-		int  ext = 0 ;
+		int ext;
 		lm85_update_client(client);
 		ext = EXT_FROM_REG(data->extend_adc, nr);
 		results[0] = INS_FROM_REG(nr,data->in_min[nr]);
@@ -1364,7 +1388,7 @@ void lm85_temp(struct i2c_client *client, int operation, int ctl_name,
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 2;
 	else if (operation == SENSORS_PROC_REAL_READ) {
-		int  ext = 0 ;
+		int ext;
 		lm85_update_client(client);
 
 		/* +5 for offset of temp data in ext reg */
