@@ -1,7 +1,7 @@
 /*
  * lm90.c - Part of lm_sensors, Linux kernel modules for hardware
  *          monitoring
- * Copyright (C) 2003-2004  Jean Delvare <khali@linux-fr.org>
+ * Copyright (C) 2003-2005  Jean Delvare <khali@linux-fr.org>
  *
  * Based on the lm83 driver. The LM90 is a sensor chip made by National
  * Semiconductor. It reports up to two temperatures (its own plus up to
@@ -31,7 +31,7 @@
  * Devices. That chip is similar to the LM90, with a few differences
  * that are not handled by this driver. Complete datasheet can be
  * obtained from Analog's website at:
- *   http://products.analog.com/products/info.asp?product=ADM1032
+ *   http://www.analog.com/en/prod/0,2877,ADM1032,00.html
  * Among others, it has a higher accuracy than the LM90, much like the
  * LM86 does.
  *
@@ -49,7 +49,7 @@
  * register values are decoded differently) it is ignored by this
  * driver. Complete datasheet can be obtained from Analog's website
  * at:
- *   http://products.analog.com/products/info.asp?product=ADT7461
+ *   http://www.analog.com/en/prod/0,2877,ADT7461,00.html
  *
  * Since the LM90 was the first chipset supported by this driver, most
  * comments will refer to this chipset, but are actually general and
@@ -85,10 +85,10 @@
  * Addresses to scan
  * Address is fully defined internally and cannot be changed except for
  * MAX6659.
- * LM86, LM89, LM90, LM99, ADM1032, MAX6657 and MAX6658 have address 0x4c.
- * LM89-1, and LM99-1 have address 0x4d.
+ * LM86, LM89, LM90, LM99, ADM1032, ADM1032-1, ADT7461, MAX6657 and MAX6658
+ * have address 0x4c.
+ * ADM1032-2, ADT7461-2, LM89-1, and LM99-1 have address 0x4d.
  * MAX6659 can have address 0x4c, 0x4d or 0x4e (unsupported).
- * ADT7461 always has address 0x4c.
  */
 
 static unsigned short normal_i2c[] = { 0x4c, 0x4d, SENSORS_I2C_END };
@@ -159,10 +159,10 @@ SENSORS_INSMOD_6(lm90, adm1032, lm99, lm86, max6657, adt7461);
 #define HYST_TO_REG(val)	((val) <= 0 ? 0 : \
 				 (val) >= 31 ? 31 : (val))
 
-/* 
+/*
  * ADT7461 is almost identical to LM90 except that attempts to write
  * values that are outside the range 0 < temp < 127 are treated as
- * the boundary value. 
+ * the boundary value.
  */
 
 #define TEMP1_TO_REG_ADT7461(val) ((val) <= 0 ? 0 : \
@@ -194,6 +194,8 @@ static void lm90_remote_hyst(struct i2c_client *client, int operation,
 	int ctl_name, int *nrels_mag, long *results);
 static void lm90_alarms(struct i2c_client *client, int operation,
 	int ctl_name, int *nrels_mag, long *results);
+static void adm1032_pec(struct i2c_client *client, int operation,
+	int ctl_name, int *nrels_mag, long *results);
 
 /*
  * Driver data (common to all clients)
@@ -211,8 +213,7 @@ static struct i2c_driver lm90_driver = {
  * Client data (each client gets its own)
  */
 
-struct lm90_data
-{
+struct lm90_data {
 	struct i2c_client client;
 	int sysctl_id;
 
@@ -243,6 +244,7 @@ struct lm90_data
 #define LM90_SYSCTL_LOCAL_HYST    1207
 #define LM90_SYSCTL_REMOTE_HYST   1208
 #define LM90_SYSCTL_ALARMS        1210
+#define LM90_SYSCTL_PEC           1214
 
 #define LM90_ALARM_LOCAL_HIGH     0x40
 #define LM90_ALARM_LOCAL_LOW      0x20
@@ -274,10 +276,65 @@ static ctl_table lm90_dir_table_template[] =
 	{0}
 };
 
+static ctl_table adm1032_dir_table_template[] =
+{
+	{LM90_SYSCTL_LOCAL_TEMP, "temp1", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_local_temp},
+	{LM90_SYSCTL_REMOTE_TEMP, "temp2", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_remote_temp},
+	{LM90_SYSCTL_LOCAL_TCRIT, "tcrit1", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_local_tcrit},
+	{LM90_SYSCTL_REMOTE_TCRIT, "tcrit2", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_remote_tcrit},
+	{LM90_SYSCTL_LOCAL_HYST, "hyst1", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_local_hyst},
+	{LM90_SYSCTL_REMOTE_HYST, "hyst2", NULL, 0, 0444, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_remote_hyst},
+	{LM90_SYSCTL_ALARMS, "alarms", NULL, 0, 0444, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &lm90_alarms},
+	{LM90_SYSCTL_PEC, "pec", NULL, 0, 0644, NULL,
+	 &i2c_proc_real, &i2c_sysctl_real, NULL, &adm1032_pec},
+	{0}
+};
+
 /*
  * Real code
  */
 
+/* The ADM1032 supports PEC but not on write byte transactions, so we need
+   to explicitly ask for a transaction without PEC. */
+static inline s32 adm1032_write_byte(struct i2c_client *client, u8 value)
+{
+	return i2c_smbus_xfer(client->adapter, client->addr,
+			      client->flags & ~I2C_CLIENT_PEC,
+			      I2C_SMBUS_WRITE, value, I2C_SMBUS_BYTE, NULL);
+}
+
+/* It is assumed that client->update_lock is held (unless we are in
+   detection or initialization steps). This matters when PEC is enabled,
+   because we don't want the address pointer to change between the write
+   byte and the read byte transactions. */
+static int lm90_read_reg(struct i2c_client* client, u8 reg, u8 *value)
+{
+	int err;
+
+ 	if (client->flags & I2C_CLIENT_PEC) {
+ 		err = adm1032_write_byte(client, reg);
+ 		if (err >= 0)
+ 			err = i2c_smbus_read_byte(client);
+ 	} else
+ 		err = i2c_smbus_read_byte_data(client, reg);
+
+	if (err < 0) {
+		printk(KERN_WARNING "lm90: Register 0x%02x read failed (%d)\n",
+		       reg, err);
+		return err;
+	}
+	*value = err;
+
+	return 0;
+}
+
 static int lm90_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, lm90_detect);
@@ -296,26 +353,16 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 	const char *type_name = "";
 	const char *client_name = "";
 
+	if (!i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE_DATA)) {
 #ifdef DEBUG
-	if (i2c_is_isa_adapter(adapter))
-	{
-		printk("lm90.o: Called for an ISA bus adapter, aborting.\n");
-		return 0;
-	}
-#endif
-
-	if (!i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE_DATA))
-	{
-#ifdef DEBUG
-		printk("lm90.o: I2C bus doesn't support byte read mode, "
-		       "skipping.\n");
+		printk(KERN_DEBUG "lm90: adapter doesn't support byte mode, "
+		       "skipping\n");
 #endif
 		return 0;
 	}
 
-	if (!(data = kmalloc(sizeof(struct lm90_data), GFP_KERNEL)))
-	{
-		printk("lm90.o: Out of memory in lm90_detect (new_client).\n");
+	if (!(data = kmalloc(sizeof(struct lm90_data), GFP_KERNEL))) {
+		printk(KERN_ERR "lm90: Out of memory in lm90_detect\n");
 		return -ENOMEM;
 	}
 
@@ -347,30 +394,29 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 	if (kind == 0)
 		kind = lm90;
 
-	if (kind < 0) /* detection and identification */
-	{
+	if (kind < 0) { /* detection and identification */
 		u8 man_id, chip_id, reg_config1, reg_convrate;
 
-		man_id = i2c_smbus_read_byte_data(new_client,
-			LM90_REG_R_MAN_ID);
-		chip_id = i2c_smbus_read_byte_data(new_client,
-			LM90_REG_R_CHIP_ID);
-		reg_config1 = i2c_smbus_read_byte_data(new_client,
-			LM90_REG_R_CONFIG1);
-		reg_convrate = i2c_smbus_read_byte_data(new_client,
-			LM90_REG_R_CONVRATE);
-		
-		if (man_id == 0x01) /* National Semiconductor */
-		{
+		if (lm90_read_reg(new_client, LM90_REG_R_MAN_ID,
+				  &man_id) < 0
+		 || lm90_read_reg(new_client, LM90_REG_R_CHIP_ID,
+		 		  &chip_id) < 0
+		 || lm90_read_reg(new_client, LM90_REG_R_CONFIG1,
+		 		  &reg_config1) < 0
+		 || lm90_read_reg(new_client, LM90_REG_R_CONVRATE,
+		 		  &reg_convrate) < 0)
+			goto exit_free;
+
+		if (man_id == 0x01) { /* National Semiconductor */
 			u8 reg_config2;
 
-			reg_config2 = i2c_smbus_read_byte_data(new_client,
-				LM90_REG_R_CONFIG2);
+			if (lm90_read_reg(new_client, LM90_REG_R_CONFIG2,
+					  &reg_config2) < 0)
+				goto exit_free;
 
 			if ((reg_config1 & 0x2A) == 0x00
 			 && (reg_config2 & 0xF8) == 0x00
-			 && reg_convrate <= 0x09)
-			{
+			 && reg_convrate <= 0x09) {
 				if (address == 0x4C
 				 && (chip_id & 0xF0) == 0x20) /* LM90 */
 					kind = lm90;
@@ -380,23 +426,19 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 				 && (chip_id & 0xF0) == 0x10) /* LM86 */
 					kind = lm99;
 			}
-		}
-		else if (man_id == 0x41) /* Analog Devices */
-		{
-			if (address == 0x4C
-			 && (chip_id & 0xF0) == 0x40 /* ADM1032 */
+		} else
+		if (man_id == 0x41) { /* Analog Devices */
+			if ((chip_id & 0xF0) == 0x40 /* ADM1032 */
 			 && (reg_config1 & 0x3F) == 0x00
 			 && reg_convrate <= 0x0A)
 				kind = adm1032;
 			else
-			if (address == 0x4c
-			 && chip_id == 0x51 /* ADT7461 */
+			if (chip_id == 0x51 /* ADT7461 */
 			 && (reg_config1 & 0x1F) == 0x00 /* check compat mode */
-			 && reg_convrate <= 0x0A) 
+			 && reg_convrate <= 0x0A)
 				kind = adt7461;
-		}
-		else if (man_id == 0x4D) /* Maxim */
-		{
+		} else
+		if (man_id == 0x4D) { /* Maxim */
  			/*
  			 * The Maxim variants do NOT have a chip_id register.
  			 * Reading from that address will return the last read
@@ -413,46 +455,38 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 		}
 	}
 
-	if (kind <= 0) /* identification failed */
-	{
-		printk("lm90.o: Unsupported chip.\n");
-		goto ERROR1;
+	if (kind <= 0) { /* identification failed */
+		printk(KERN_INFO "lm90: Unsupported chip\n");
+		goto exit_free;
 	}
 
-	if (kind == lm90)
-	{
+	if (kind == lm90) {
 		type_name = "lm90";
 		client_name = "LM90 chip";
-	}
-	else if (kind == adm1032)
-	{
+	} else if (kind == adm1032) {
 		type_name = "adm1032";
 		client_name = "ADM1032 chip";
-	}
-	else if (kind == lm99)
-	{
+		/* The ADM1032 supports PEC, but only if combined
+		   transactions are not used. */
+		if (i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE)) {
+			new_client->flags |= I2C_CLIENT_PEC;
+			printk(KERN_DEBUG "lm90: Enabling PEC for ADM1032\n");
+		}
+	} else if (kind == lm99) {
 		type_name = "lm99";
 		client_name = "LM99 chip";
-	}
-	else if (kind == lm86)
-	{
+	} else if (kind == lm86) {
 		type_name = "lm86";
 		client_name = "LM86 chip";
-	}
-	else if (kind == max6657)
-	{
+	} else if (kind == max6657) {
 		type_name = "max6657";
 		client_name = "MAX6657 chip";
-	}
-	else if (kind == adt7461)
-	{
+	} else if (kind == adt7461) {
 		type_name = "adt7461";
 		client_name = "ADT7561 chip";
-	}
-	else
-	{
-		printk("lm90.o: Unknown kind %d.\n", kind);
-		goto ERROR1;
+	} else {
+		printk(KERN_ERR "lm90: Unknown kind %d\n", kind);
+		goto exit_free;
 	}
 
 	/*
@@ -469,12 +503,9 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 	 * Tell the I2C layer a new client has arrived.
 	 */
 
-	if ((err = i2c_attach_client(new_client)))
-	{
-#ifdef DEBUG
-		printk("lm90.o: Failed attaching client.\n");
-#endif
-		goto ERROR1;
+	if ((err = i2c_attach_client(new_client))) {
+		printk(KERN_ERR "lm90: Failed to attach client (%d)\n", err);
+		goto exit_free;
 	}
 
 	/*
@@ -482,12 +513,12 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 	 */
 
 	if ((err = i2c_register_entry(new_client, type_name,
-	     lm90_dir_table_template, THIS_MODULE)) < 0)
-	{
-#ifdef DEBUG
-		printk("lm90.o: Failed registering directory entry.\n");
-#endif
-		goto ERROR2;
+	     (new_client->flags & I2C_CLIENT_PEC) ?
+	     adm1032_dir_table_template :
+	     lm90_dir_table_template, THIS_MODULE)) < 0) {
+		printk(KERN_ERR "lm90: Failed to register directory entry "
+		       "(%d)\n", err);
+		goto exit_detach;
 	}
 	data->sysctl_id = err;
 
@@ -498,9 +529,9 @@ static int lm90_detect(struct i2c_adapter *adapter, int address,
 	lm90_init_client(new_client);
 	return 0;
 
-	ERROR2:
+exit_detach:
 	i2c_detach_client(new_client);
-	ERROR1:
+exit_free:
 	kfree(data);
 	return err;
 }
@@ -515,7 +546,10 @@ static void lm90_init_client(struct i2c_client *client)
 
 	i2c_smbus_write_byte_data(client, LM90_REG_W_CONVRATE,
 		5); /* 2 Hz */
-	config = i2c_smbus_read_byte_data(client, LM90_REG_R_CONFIG1);
+	if (lm90_read_reg(client, LM90_REG_R_CONFIG1, &config) < 0) {
+		printk(KERN_ERR "lm90: Initialization failed!\n");
+		return;
+	}
 	if (config & 0x40)
 		i2c_smbus_write_byte_data(client, LM90_REG_W_CONFIG1,
 			config & 0xBF); /* run */
@@ -527,10 +561,9 @@ static int lm90_detach_client(struct i2c_client *client)
 	int err;
 
 	i2c_deregister_entry(((struct lm90_data *) (client->data))->sysctl_id);
-	if ((err = i2c_detach_client(client)))
-	{
-		printk("lm90.o: Client deregistration failed, client not "
-		       "detached.\n");
+	if ((err = i2c_detach_client(client))) {
+		printk(KERN_ERR "lm90: Client deregistration failed, client "
+		       "not detached (%d)\n", err);
 		return err;
 	}
 
@@ -545,21 +578,24 @@ static void lm90_update_client(struct i2c_client *client)
 	down(&data->update_lock);
 
 	if ((jiffies - data->last_updated > HZ * 2) ||
-	    (jiffies < data->last_updated) || !data->valid)
-	{
-		u8 oldh, newh;
+	    (jiffies < data->last_updated) || !data->valid) {
+		u8 oldh, newh, l;
 #ifdef DEBUG
-		printk("lm90.o: Updating data.\n");
+		printk(KERN_DEBUG "lm90: Updating register values\n");
 #endif
 
-		data->local_temp =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_LOCAL_TEMP);
-		data->local_high =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_LOCAL_HIGH);
-		data->local_low =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_LOCAL_LOW);
-		data->local_crit =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_LOCAL_CRIT);
+		lm90_read_reg(client, LM90_REG_R_LOCAL_TEMP,
+			      &data->local_temp);
+		lm90_read_reg(client, LM90_REG_R_LOCAL_HIGH,
+			      &data->local_high);
+		lm90_read_reg(client, LM90_REG_R_LOCAL_LOW,
+			      &data->local_low);
+		lm90_read_reg(client, LM90_REG_R_LOCAL_CRIT,
+			      &data->local_crit);
+		lm90_read_reg(client, LM90_REG_R_REMOTE_CRIT,
+			      &data->remote_crit);
+		lm90_read_reg(client, LM90_REG_R_TCRIT_HYST,
+			      &data->hyst);
 
 		/*
 		 * There is a trick here. We have to read two registers to
@@ -576,37 +612,20 @@ static void lm90_update_client(struct i2c_client *client)
 		 * byte again, and now we believe we have a correct reading.
 		 */
 
-		oldh =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_TEMPH);
-		data->remote_temp =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_TEMPL);
-		newh =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_TEMPH);
-		if (newh != oldh)
-		{
-			data->remote_temp =
-				i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_TEMPL);
-#ifdef DEBUG
-			oldh = /* actually newer */
-				i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_TEMPH);
-			if (newh != oldh)
-				printk("lm90.o: Remote temperature may be wrong.\n");
-#endif
-		}
-		data->remote_temp |= (newh << 8);
-		data->remote_high =
-			(i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_HIGHH) << 8)
-			+ i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_HIGHL);
-		data->remote_low =
-			(i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_LOWH) << 8)
-			+ i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_LOWL);
-		data->remote_crit =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_REMOTE_CRIT);
+		if (lm90_read_reg(client, LM90_REG_R_REMOTE_TEMPH, &oldh) == 0
+		 && lm90_read_reg(client, LM90_REG_R_REMOTE_TEMPL, &l) == 0
+		 && lm90_read_reg(client, LM90_REG_R_REMOTE_TEMPH, &newh) == 0
+		 && (newh == oldh
+		  || lm90_read_reg(client, LM90_REG_R_REMOTE_TEMPL, &l) == 0))
+			data->remote_temp = (newh << 8) | l;
 
-		data->hyst =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_TCRIT_HYST);
-		data->alarms =
-			i2c_smbus_read_byte_data(client, LM90_REG_R_STATUS);
+		if (lm90_read_reg(client, LM90_REG_R_REMOTE_LOWH, &newh) == 0
+		 && lm90_read_reg(client, LM90_REG_R_REMOTE_LOWL, &l) == 0)
+			data->remote_low = (newh << 8) | l;
+		if (lm90_read_reg(client, LM90_REG_R_REMOTE_HIGHH, &newh) == 0
+		 && lm90_read_reg(client, LM90_REG_R_REMOTE_HIGHL, &l) == 0)
+			data->remote_high = (newh << 8) | l;
+		lm90_read_reg(client, LM90_REG_R_STATUS, &data->alarms);
 
 		data->last_updated = jiffies;
 		data->valid = 1;
@@ -622,18 +641,14 @@ static void lm90_local_temp(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP1_FROM_REG(data->local_high);
 		results[1] = TEMP1_FROM_REG(data->local_low);
 		results[2] = TEMP1_FROM_REG(data->local_temp);
 		*nrels_mag = 3;
-	}
-	else if (operation == SENSORS_PROC_REAL_WRITE)
-	{
-		if (*nrels_mag >= 1)
-		{
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
 			if (data->kind == adt7461)
 				data->local_high = TEMP1_TO_REG_ADT7461(results[0]);
 			else
@@ -641,8 +656,7 @@ static void lm90_local_temp(struct i2c_client *client, int operation,
 			i2c_smbus_write_byte_data(client, LM90_REG_W_LOCAL_HIGH,
 				data->local_high);
 		}
-		if (*nrels_mag >= 2)
-		{
+		if (*nrels_mag >= 2) {
 			if (data->kind == adt7461)
 				data->local_low = TEMP1_TO_REG_ADT7461(results[1]);
 			else
@@ -660,32 +674,27 @@ static void lm90_remote_temp(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 1; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP2_FROM_REG(data->remote_high);
 		results[1] = TEMP2_FROM_REG(data->remote_low);
 		results[2] = TEMP2_FROM_REG(data->remote_temp);
 		*nrels_mag = 3;
-	}
-	else if (operation == SENSORS_PROC_REAL_WRITE)
-	{
-		if (*nrels_mag >= 1)
-		{
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
 			if (data->kind == adt7461)
 				data->remote_high = TEMP2_TO_REG_ADT7461(results[0]);
-			else 
+			else
 				data->remote_high = TEMP2_TO_REG(results[0]);
 			i2c_smbus_write_byte_data(client, LM90_REG_W_REMOTE_HIGHH,
 				data->remote_high >> 8);
 			i2c_smbus_write_byte_data(client, LM90_REG_W_REMOTE_HIGHL,
 				data->remote_high & 0xFF);
 		}
-		if (*nrels_mag >= 2)
-		{
+		if (*nrels_mag >= 2) {
 			if (data->kind == adt7461)
 				data->remote_low = TEMP2_TO_REG_ADT7461(results[1]);
-			else 
+			else
 				data->remote_low = TEMP2_TO_REG(results[1]);
 			i2c_smbus_write_byte_data(client, LM90_REG_W_REMOTE_LOWH,
 				data->remote_low >> 8);
@@ -702,16 +711,12 @@ static void lm90_local_tcrit(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP1_FROM_REG(data->local_crit);
 		*nrels_mag = 1;
-	}
-	else if (operation == SENSORS_PROC_REAL_WRITE)
-	{
-		if (*nrels_mag >= 1)
-		{
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
 			if (data->kind == adt7461)
 				data->local_crit = TEMP1_TO_REG_ADT7461(results[0]);
 			else
@@ -729,16 +734,12 @@ static void lm90_remote_tcrit(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP1_FROM_REG(data->remote_crit);
 		*nrels_mag = 1;
-	}
-	else if (operation == SENSORS_PROC_REAL_WRITE)
-	{
-		if (*nrels_mag >= 1)
-		{
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
 			if (data->kind == adt7461)
 				data->remote_crit = TEMP1_TO_REG_ADT7461(results[0]);
 			else
@@ -771,17 +772,13 @@ static void lm90_local_hyst(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP1_FROM_REG(data->local_crit) -
 			TEMP1_FROM_REG(data->hyst);
 		*nrels_mag = 1;
-	}
-	else if (operation == SENSORS_PROC_REAL_WRITE)
-	{
-		if (*nrels_mag >= 1)
-		{
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
 			data->hyst = HYST_TO_REG(data->local_crit - results[0]);
 			i2c_smbus_write_byte_data(client, LM90_REG_W_TCRIT_HYST,
 				data->hyst);
@@ -796,8 +793,7 @@ static void lm90_remote_hyst(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = TEMP1_FROM_REG(data->remote_crit) -
 			TEMP1_FROM_REG(data->hyst);
@@ -812,17 +808,40 @@ static void lm90_alarms(struct i2c_client *client, int operation,
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0; /* magnitude */
-	else if (operation == SENSORS_PROC_REAL_READ)
-	{
+	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm90_update_client(client);
 		results[0] = data->alarms;
 		*nrels_mag = 1;
 	}
 }
 
+/* pec used for ADM1032 only */
+static void adm1032_pec(struct i2c_client *client, int operation,
+	int ctl_name, int *nrels_mag, long *results)
+{
+	if (operation == SENSORS_PROC_REAL_INFO)
+		*nrels_mag = 0; /* magnitude */
+	else if (operation == SENSORS_PROC_REAL_READ) {
+		results[0] = !!(client->flags & I2C_CLIENT_PEC);
+		*nrels_mag = 1;
+	} else if (operation == SENSORS_PROC_REAL_WRITE) {
+		if (*nrels_mag >= 1) {
+			switch (results[0]) {
+			case 0:
+				client->flags &= ~I2C_CLIENT_PEC;
+				break;
+			case 1:
+				client->flags |= I2C_CLIENT_PEC;
+				break;
+			}
+		}
+	}
+}
+
 static int __init sm_lm90_init(void)
 {
-	printk(KERN_INFO "lm90.o version %s (%s)\n", LM_VERSION, LM_DATE);
+	printk(KERN_INFO "lm90 driver version %s (%s)\n", LM_VERSION,
+	       LM_DATE);
 	return i2c_add_driver(&lm90_driver);
 }
 
