@@ -207,7 +207,7 @@ static inline u8 FAN_TO_REG(long rpm, int div)
 // but the function is very linear in the useful range (0-80 deg C), so 
 // we'll just use linear interpolation for 10-bit readings.)  So, tempLUT 
 // is the temp at via register values 0-255:
-static const long tempLUT[] =
+static const s16 tempLUT[] =
     { -709, -688, -667, -646, -627, -607, -589, -570, -553, -536, -519,
 	    -503, -487, -471, -456, -442, -428, -414, -400, -387, -375,
 	    -362, -350, -339, -327, -316, -305, -295, -285, -275, -265,
@@ -568,9 +568,10 @@ static void via686a_init_client(struct i2c_client *client)
 	via686a_write_value(client, VIA686A_REG_CONFIG, (reg|0x01)&0x7F);
 
 	/* Configure temp interrupt mode for continuous-interrupt operation */
+	reg = via686a_read_value(client, VIA686A_REG_TEMP_MODE);
 	via686a_write_value(client, VIA686A_REG_TEMP_MODE, 
-			    via686a_read_value(client, VIA686A_REG_TEMP_MODE) &
-			    !(VIA686A_TEMP_MODE_MASK | VIA686A_TEMP_MODE_CONTINUOUS));
+			    (reg & ~VIA686A_TEMP_MODE_MASK)
+			    | VIA686A_TEMP_MODE_CONTINUOUS);
 }
 
 static void via686a_update_client(struct i2c_client *client)
@@ -802,10 +803,6 @@ static int __devinit via686a_pci_probe(struct pci_dev *dev,
        if (force_addr)
                addr = force_addr;      /* so detect will get called */
 
-       if (!addr) {
-               printk("via686a.o: No Via 686A sensors found.\n");
-               return -ENODEV;
-       }
        normal_isa[0] = addr;
        s_bridge = dev;
        return i2c_add_driver(&via686a_driver);
