@@ -1182,7 +1182,7 @@
 /* THMC50/ADM1022 chips */
 
 #define SENSORS_THMC50_PREFIX "thmc50"
-/* Cheat on LM84,GL523,THMC10 for now - no separate #defines */
+/* Cheat on ADM1022 for now - no separate #defines */
 #define SENSORS_ADM1022_PREFIX "adm1022"
 
 #define SENSORS_THMC50_TEMP 51 /* R */
@@ -1191,6 +1191,9 @@
 #define SENSORS_THMC50_REMOTE_TEMP 54 /* R */
 #define SENSORS_THMC50_REMOTE_TEMP_HYST 55 /* RW */
 #define SENSORS_THMC50_REMOTE_TEMP_OVER 56 /* RW */
+#define SENSORS_ADM1022_REMOTE_TEMP2 57 /* R */
+#define SENSORS_ADM1022_REMOTE_TEMP2_HYST 58 /* RW */
+#define SENSORS_ADM1022_REMOTE_TEMP2_OVER 59 /* RW */
 #define SENSORS_THMC50_ANALOG_OUT 71 /* RW */
 #define SENSORS_THMC50_INTER 81 /* R */
 #define SENSORS_THMC50_INTER_MASK 82 /* RW */
@@ -2274,9 +2277,10 @@
 #define SENSORS_CORETEMP_TEMP1_CRIT		0x02 /* R */
 #define SENSORS_CORETEMP_TEMP1_CRIT_ALARM	0x03 /* R */
 
-/* DME1737 */
+/* DME1737 chips */
 
 #define SENSORS_DME1737_PREFIX "dme1737"
+#define SENSORS_SCH311X_PREFIX "sch311x"
 
 /* in n from 0 to 6 */
 #define SENSORS_DME1737_IN(n)			(0x01 + (n)) /* R */
@@ -2337,4 +2341,26 @@
 #define SENSORS_F71882FG_TEMP_FAULT(n)		(140 + (n))
 #define SENSORS_F71882FG_TEMP_TYPE(n)		(150 + (n))
 
+/* Fujitsu Siemens Computers Heimdal and Heracles */
+#define SENSORS_FSCHMD_PREFIX		"fscher"
+#define SENSORS_FSCHRC_PREFIX		"fscher"
+
+/* Note, we start with feature numbers of 60+ to not have any overlapping
+   features with the old FSCPOS, FSCSCY and FSCHER feature lists, as the
+   FSCHMD feature defines for features only exported by the new FSCHMD driver
+   are reused in the feature lists of the FSCPOS, FSCSCY and FSCHER */
+   
+/* in n from 0 to 3 */
+#define SENSORS_FSCHMD_IN(n)			(60 + (n))
+/* fan n from 1 to 5 (4 for the hrc) */
+#define SENSORS_FSCHMD_FAN(n)			(70 + (n))
+#define SENSORS_FSCHMD_FAN_DIV(n)		(80 + (n))
+#define SENSORS_FSCHMD_FAN_ALARM(n)		(90 + (n))
+#define SENSORS_FSCHMD_FAN_FAULT(n)		(100 + (n))
+/* temp n from 1 to 5 (3 for the hrc) */
+#define SENSORS_FSCHMD_TEMP(n)			(110 + (n))
+#define SENSORS_FSCHMD_TEMP_MAX(n)		(120 + (n))
+#define SENSORS_FSCHMD_TEMP_ALARM(n)		(130 + (n))
+#define SENSORS_FSCHMD_TEMP_FAULT(n)		(140 + (n))
+
 #endif /* def LIB_SENSORS_CHIPS_H */
