@@ -111,11 +111,10 @@ typedef struct sensors_chip {
 } sensors_chip;
 
 /* Config file bus declaration: the i2c bus number, combined with adapter
-   and algorithm names */
+   name */
 typedef struct sensors_bus {
   int number;
   char *adapter;
-  char *algorithm;
   int lineno;
 } sensors_bus;
 
@@ -151,11 +150,7 @@ typedef struct sensors_proc_chips_entry {
      Scaling can be positive or negative but negative values aren't
      very useful because the driver can scale that direction itself. */
 typedef struct sensors_chip_feature {
-  int number;
-  const char *name;
-  int logical_mapping;
-  int compute_mapping;
-  int mode;
+  sensors_feature_data data;
   int sysctl;
   int offset;
   int scaling;
@@ -182,10 +177,18 @@ extern sensors_proc_chips_entry *sensors_proc_chips;
 extern int sensors_proc_chips_count;
 extern int sensors_proc_chips_max;
 
+#define sensors_add_proc_chips(el) sensors_add_array_el( \
+	(el), &sensors_proc_chips, &sensors_proc_chips_count,\
+	&sensors_proc_chips_max, sizeof(struct sensors_proc_chips_entry))
+
 extern sensors_bus *sensors_proc_bus;
 extern int sensors_proc_bus_count;
 extern int sensors_proc_bus_max;
 
+#define sensors_add_proc_bus(el) sensors_add_array_el( \
+	(el), &sensors_proc_bus, &sensors_proc_bus_count,\
+	&sensors_proc_bus_max, sizeof(struct sensors_bus))
+
 extern sensors_chip_features sensors_chip_features_list[];
 
 #endif /* def LIB_SENSORS_DATA_H */
