@@ -244,7 +244,7 @@ int main(int argc, char *argv[])
 			        strerror(errno));
 			exit(1);
 		}
-		if (!(funcs & (I2C_FUNC_SMBUS_HWPEC_CALC | I2C_FUNC_I2C))) {
+		if (!(funcs & (I2C_FUNC_SMBUS_PEC | I2C_FUNC_I2C))) {
 			fprintf(stderr, "Warning: Adapter for i2c bus %d does "
 			        "not seem to actually support PEC\n", i2cbus);
 		}
