@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2002-2004 Jean Delvare <khali@linux-fr.org>
+# Copyright (C) 2002-2006 Jean Delvare <khali@linux-fr.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -37,6 +37,12 @@
 #  Added some documentation.
 # Version 1.1  2004-01-17  Jean Delvare <khali@linux-fr.org>
 #  Added support for Linux 2.5/2.6 (i.e. sysfs).
+# Version 1.2  2004-11-28  Jean Delvare <khali@linux-fr.org>
+#  Support bus number 0 to 4 instead of only 0.
+# Version 1.3  2005-01-18  Jean Delvare <khali@linux-fr.org>
+#  Revision might be a Service Tag.
+# Version 1.4  2006-09-20  Jean Delvare <khali@linux-fr.org>
+#  Detect and skip false positives (e.g. EDID EEPROMs).
 #
 # EEPROM data decoding for Sony Vaio laptops. 
 #
@@ -62,16 +68,18 @@
 #   PCG-U1       : OK
 #   PCG-Z600LEK  : No EEPROM
 #   PCG-Z600NE   : No EEPROM
+#   VGN-S260     : OK
+#   VGN-S4M/S    : OK
 # Any feedback appreciated anyway.
 #
 # Thanks to Werner Heuser, Carsten Blume, Christian Gennerat, Joe Wreschnig,
-# Xavier Roche, Sebastien Lefevre, Lars Heer, Steve Dobson and others for
-# their precious help.
-#
+# Xavier Roche, Sebastien Lefevre, Lars Heer, Steve Dobson, Kent Hunt and
+# others for their precious help.
+
 
 use strict;
 use Fcntl qw(:DEFAULT :seek);
-use vars qw($sysfs);
+use vars qw($sysfs $found);
 
 sub print_item
 {
@@ -174,22 +182,27 @@ sub vaio_decode
 {
 	my ($bus,$addr) = @_;
 	
-	print_item('Machine Name', decode_string($bus, $addr, 128, 32));
+	my $name = decode_string($bus, $addr, 128, 32);
+	# Simple heuristic to skip false positives
+	return 0 unless $name =~ m/^[A-Z-]{4}/;
+
+	print_item('Machine Name', $name);
 	print_item('Serial Number', decode_string($bus, $addr, 192, 32));
 	print_item('UUID', decode_uuid($bus, $addr, 16));
-	print_item('Revision', decode_string($bus, $addr, 160, 10));
+	my $revision = decode_string($bus, $addr, 160, 10);
+	print_item(length($revision) > 2 ? 'Service Tag' : 'Revision',
+		   $revision);
 	print_item('Model Name', 'PCG-'.decode_string($bus, $addr, 170, 4));
 	print_item('OEM Data', decode_string($bus, $addr, 32, 16));
 	print_item('Timestamp', decode_string($bus, $addr, 224, 32));
+	return 1;
 }
 
 BEGIN
 {
 	print("Sony Vaio EEPROM Decoder\n");
-	print("Copyright (c) 2002-2004  Jean Delvare\n");
-	print("Version 1.1\n\n");
-	
-	$sysfs = 0;
+	print("Copyright (C) 2002-2006  Jean Delvare\n");
+	print("Version 1.4\n\n");
 }
 
 END
@@ -197,23 +210,29 @@ END
 	print("\n");
 }
 
-if (-r '/proc/sys/dev/sensors/eeprom-i2c-0-57')
+for (my $i = 0, $found=0; $i <= 4 && !$found; $i++)
 {
-	if (-r '/proc/sys/dev/sensors/eeprom-i2c-0-57/data0-15')
+	if (-r "/sys/bus/i2c/devices/$i-0057/eeprom")
 	{
-		print("Deprecated old interface found.  Please upgrade to lm_sensors 2.6.3 or greater.");
+		$sysfs = 1;
+		$found += vaio_decode($i, '57');
 	}
-	else
+	elsif (-r "/proc/sys/dev/sensors/eeprom-i2c-$i-57")
 	{
-		vaio_decode('0', '57');
+		if (-r "/proc/sys/dev/sensors/eeprom-i2c-$i-57/data0-15")
+		{
+			print("Deprecated old interface found.  Please upgrade to lm_sensors 2.6.3 or greater.");
+			exit;
+		}
+		else
+		{
+			$sysfs = 0;
+			$found += vaio_decode($i, '57');
+		}
 	}
 }
-elsif (-r '/sys/bus/i2c/devices/0-0057/eeprom')
-{
-	$sysfs = 1;
-	vaio_decode('0', '57');
-}
-else
+
+if (!$found)
 {
 	print("Vaio EEPROM not found.  Please make sure that the eeprom module is loaded.\n");
 	print("If you believe this is an error, please contact me <khali\@linux-fr.org>\n");
