@@ -28,16 +28,6 @@
 #include "lib/chips.h"
 #include "kernel/include/sensors.h"
 
-/* NB:
- *
- * The following chips from prog/sensors are not (yet) supported:
- *
- * lm87 mtp008 fscpos fscscy pcf8591 vt1211 smsc47m1 lm92 adm1024 lm83
- */
-
-/* NB: missing from sensors (and this) but in lib/chips.h:
- * "gl520sm", "thmc50", "adm1022" */
-
 /* TODO: Temp in C/F */
 
 /** formatters **/
@@ -89,6 +79,13 @@ fmtTemps_minmax_0
  return fmtExtra (alarm, beep);
 }
 
+static const char *
+fmtTemp_only
+(const double values[], int alarm, int beep) {
+  sprintf (buff, "%.1f C", values[0]);
+  return fmtExtra (alarm, beep);
+}
+
 static const char *
 fmtVolt_2
 (const double values[], int alarm, int beep) {
@@ -117,6 +114,13 @@ fmtFans_0
   return fmtExtra (alarm, beep);
 }
 
+static const char *
+fmtFans_nodiv_0
+(const double values[], int alarm, int beep) {
+  sprintf (buff, "%.0f RPM (min = %.0f RPM)", values[0], values[1]);
+  return fmtExtra (alarm, beep);
+}
+
 static const char *
 fmtMHz_2
 (const double values[], int alarm, int beep) {
@@ -543,6 +547,42 @@ static const ChipDescriptor lm80_chip = {
   lm80_names, lm80_features, SENSORS_LM80_ALARMS, 0
 };
 
+/** LM87 **/
+
+static const char *lm87_names[] = {
+  SENSORS_LM87_PREFIX, NULL
+};
+
+static const FeatureDescriptor lm87_features[] = {
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN0, 0,
+    { SENSORS_LM87_IN0, SENSORS_LM87_IN0_MIN, SENSORS_LM87_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN1, 0,
+    { SENSORS_LM87_IN1, SENSORS_LM87_IN1_MIN, SENSORS_LM87_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN2, 0,
+    { SENSORS_LM87_IN2, SENSORS_LM87_IN2_MIN, SENSORS_LM87_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN3, 0,
+    { SENSORS_LM87_IN3, SENSORS_LM87_IN3_MIN, SENSORS_LM87_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN4, 0,
+    { SENSORS_LM87_IN4, SENSORS_LM87_IN4_MIN, SENSORS_LM87_IN4_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, LM87_ALARM_IN5, 0,
+    { SENSORS_LM87_IN5, SENSORS_LM87_IN5_MIN, SENSORS_LM87_IN5_MAX, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, LM87_ALARM_FAN1, 0,
+    { SENSORS_LM87_FAN1, SENSORS_LM87_FAN1_MIN, SENSORS_LM87_FAN1_DIV, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, LM87_ALARM_FAN2, 0,
+    { SENSORS_LM87_FAN2, SENSORS_LM87_FAN2_MIN, SENSORS_LM87_FAN2_DIV, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP1, 0,
+    { SENSORS_LM87_TEMP1, SENSORS_LM87_TEMP1_HYST, SENSORS_LM87_TEMP1_OVER, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP2, 0,
+    { SENSORS_LM87_TEMP2, SENSORS_LM87_TEMP2_HYST, SENSORS_LM87_TEMP2_OVER, -1 } },
+  { fmtTemps_minmax_0, rrdF1, DataType_temperature, LM87_ALARM_TEMP3, 0,
+    { SENSORS_LM87_TEMP3, SENSORS_LM87_TEMP3_HYST, SENSORS_LM87_TEMP3_OVER, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor lm87_chip = {
+  lm87_names, lm87_features, SENSORS_LM87_ALARMS, 0
+};
+
 /** IT87 (thanks to Mike Black) **/
 
 static const char *it87_names[] = {
@@ -1093,10 +1133,41 @@ static const ChipDescriptor pc87360_chip = {
   pc87360_names, pc87360_features, SENSORS_PC87360_ALARMS_TEMP, 0
 };
 
-/** W83627EHF **/
+/** PC87427 **/
+
+static const char *pc87427_names[] = {
+  SENSORS_PC87427_PREFIX,
+  NULL
+};
+
+static const FeatureDescriptor pc87427_features[] = {
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(1), SENSORS_PC87427_FAN_MIN(1), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(2), SENSORS_PC87427_FAN_MIN(2), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(3), SENSORS_PC87427_FAN_MIN(3), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(4), SENSORS_PC87427_FAN_MIN(4), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(5), SENSORS_PC87427_FAN_MIN(5), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(6), SENSORS_PC87427_FAN_MIN(6), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(7), SENSORS_PC87427_FAN_MIN(7), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_PC87427_FAN(8), SENSORS_PC87427_FAN_MIN(8), -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor pc87427_chip = {
+  pc87427_names, pc87427_features, 0, 0
+};
+
+/** W83627EHF & W83627DHG **/
 
 static const char *w83627ehf_names[] = {
-  SENSORS_W83627EHF_PREFIX, NULL
+  SENSORS_W83627EHF_PREFIX, SENSORS_W83627DHG_PREFIX, NULL
 };
 
 static const FeatureDescriptor w83627ehf_features[] = {
@@ -1116,6 +1187,26 @@ static const FeatureDescriptor w83627ehf_features[] = {
     { SENSORS_W83627EHF_TEMP2, SENSORS_W83627EHF_TEMP2_OVER, SENSORS_W83627EHF_TEMP2_HYST, -1 } },
   { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
     { SENSORS_W83627EHF_TEMP3, SENSORS_W83627EHF_TEMP3_OVER, SENSORS_W83627EHF_TEMP3_HYST, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN0, SENSORS_W83627EHF_IN0_MIN, SENSORS_W83627EHF_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN1, SENSORS_W83627EHF_IN1_MIN, SENSORS_W83627EHF_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN2, SENSORS_W83627EHF_IN2_MIN, SENSORS_W83627EHF_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN3, SENSORS_W83627EHF_IN3_MIN, SENSORS_W83627EHF_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN4, SENSORS_W83627EHF_IN4_MIN, SENSORS_W83627EHF_IN4_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN5, SENSORS_W83627EHF_IN5_MIN, SENSORS_W83627EHF_IN5_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN6, SENSORS_W83627EHF_IN6_MIN, SENSORS_W83627EHF_IN6_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN7, SENSORS_W83627EHF_IN7_MIN, SENSORS_W83627EHF_IN7_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN8, SENSORS_W83627EHF_IN8_MIN, SENSORS_W83627EHF_IN8_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83627EHF_IN9, SENSORS_W83627EHF_IN9_MIN, SENSORS_W83627EHF_IN9_MAX, -1 } },
   { NULL }
 };
 
@@ -1148,12 +1239,12 @@ static const FeatureDescriptor f71805f_features[] = {
     { SENSORS_F71805F_IN(7), SENSORS_F71805F_IN_MIN(7), SENSORS_F71805F_IN_MAX(7), -1 } },
   { fmtVolts_2, rrdF3, DataType_voltage, 0, 0,
     { SENSORS_F71805F_IN(8), SENSORS_F71805F_IN_MIN(8), SENSORS_F71805F_IN_MAX(8), -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(1), SENSORS_F71805F_FAN_MIN(1), -1, -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(2), SENSORS_F71805F_FAN_MIN(2), -1, -1 } },
-  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
-    { SENSORS_F71805F_FAN(3), SENSORS_F71805F_FAN_MIN(3), -1, -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(1), SENSORS_F71805F_FAN_MIN(1), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(2), SENSORS_F71805F_FAN_MIN(2), -1 } },
+  { fmtFans_nodiv_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_F71805F_FAN(3), SENSORS_F71805F_FAN_MIN(3), -1 } },
   { fmtTemps_0, rrdF0, DataType_temperature, 1 << 0, 0,
     { SENSORS_F71805F_TEMP(1), SENSORS_F71805F_TEMP_MAX(1), SENSORS_F71805F_TEMP_HYST(1), -1 } },
   { fmtTemps_0, rrdF0, DataType_temperature, 1 << 1, 0,
@@ -1168,6 +1259,143 @@ static const ChipDescriptor f71805f_chip = {
   f71805f_names, f71805f_features, SENSORS_F71805F_ALARMS_TEMP, 0
 };
 
+/** VT1211 **/
+
+static const char *vt1211_names[] = {
+  SENSORS_VT1211_PREFIX, NULL
+};
+
+static const FeatureDescriptor vt1211_features[] = {
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN0, 0,
+    { SENSORS_VT1211_IN0, SENSORS_VT1211_IN0_MIN, SENSORS_VT1211_IN0_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN1, 0,
+    { SENSORS_VT1211_IN1, SENSORS_VT1211_IN1_MIN, SENSORS_VT1211_IN1_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN2, 0,
+    { SENSORS_VT1211_IN2, SENSORS_VT1211_IN2_MIN, SENSORS_VT1211_IN2_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN3, 0,
+    { SENSORS_VT1211_IN3, SENSORS_VT1211_IN3_MIN, SENSORS_VT1211_IN3_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN4, 0,
+    { SENSORS_VT1211_IN4, SENSORS_VT1211_IN4_MIN, SENSORS_VT1211_IN4_MAX, -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, VT1211_ALARM_IN5, 0,
+    { SENSORS_VT1211_IN5, SENSORS_VT1211_IN5_MIN, SENSORS_VT1211_IN5_MAX, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, VT1211_ALARM_FAN1, 0,
+    { SENSORS_VT1211_FAN1, SENSORS_VT1211_FAN1_MIN, SENSORS_VT1211_FAN1_DIV, -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, VT1211_ALARM_FAN2, 0,
+    { SENSORS_VT1211_FAN2, SENSORS_VT1211_FAN2_MIN, SENSORS_VT1211_FAN2_DIV, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP1, 0,
+    { SENSORS_VT1211_TEMP1, SENSORS_VT1211_TEMP1_OVER, SENSORS_VT1211_TEMP1_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP2, 0,
+    { SENSORS_VT1211_TEMP2, SENSORS_VT1211_TEMP2_OVER, SENSORS_VT1211_TEMP2_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP3, 0,
+    { SENSORS_VT1211_TEMP3, SENSORS_VT1211_TEMP3_OVER, SENSORS_VT1211_TEMP3_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP4, 0,
+    { SENSORS_VT1211_TEMP4, SENSORS_VT1211_TEMP4_OVER, SENSORS_VT1211_TEMP4_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP5, 0,
+    { SENSORS_VT1211_TEMP5, SENSORS_VT1211_TEMP5_OVER, SENSORS_VT1211_TEMP5_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP6, 0,
+    { SENSORS_VT1211_TEMP6, SENSORS_VT1211_TEMP6_OVER, SENSORS_VT1211_TEMP6_HYST, -1 } },
+  { fmtTemps_1_0, rrdF1, DataType_temperature, VT1211_ALARM_TEMP7, 0,
+    { SENSORS_VT1211_TEMP7, SENSORS_VT1211_TEMP7_OVER, SENSORS_VT1211_TEMP7_HYST, -1 } },
+  { fmtVolt_3, rrdF3, DataType_voltage, 0, 0,
+    { SENSORS_VT1211_VID, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor vt1211_chip = {
+  vt1211_names, vt1211_features, SENSORS_VT1211_ALARMS, 0
+};
+
+/** K8 **/
+
+static const char *k8temp_names[] = {
+  SENSORS_K8TEMP_PREFIX, NULL
+};
+
+static const FeatureDescriptor k8temp_features[] = {
+  { fmtTemp_only, rrdF0, DataType_temperature, 0, 0,
+    { SENSORS_K8TEMP_TEMP1, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor k8temp_chip = {
+  k8temp_names, k8temp_features, 0, 0
+};
+
+/** W83793 **/
+
+static const char *w83793_names[] = {
+  SENSORS_W83793_PREFIX, NULL
+};
+
+static const FeatureDescriptor w83793_features[] = {
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(1), SENSORS_W83793_FAN_MIN(1), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(2), SENSORS_W83793_FAN_MIN(2), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(3), SENSORS_W83793_FAN_MIN(3), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(4), SENSORS_W83793_FAN_MIN(4), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(5), SENSORS_W83793_FAN_MIN(5), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(6), SENSORS_W83793_FAN_MIN(6), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(7), SENSORS_W83793_FAN_MIN(7), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(8), SENSORS_W83793_FAN_MIN(8), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(9), SENSORS_W83793_FAN_MIN(9), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(10), SENSORS_W83793_FAN_MIN(10), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(11), SENSORS_W83793_FAN_MIN(11), -1 } },
+  { fmtFans_0, rrdF0, DataType_rpm, 0, 0,
+    { SENSORS_W83793_FAN(12), SENSORS_W83793_FAN_MIN(12), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(1), SENSORS_W83793_TEMP_CRIT(1), SENSORS_W83793_TEMP_CRIT_HYST(1), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(2), SENSORS_W83793_TEMP_CRIT(2), SENSORS_W83793_TEMP_CRIT_HYST(2), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(3), SENSORS_W83793_TEMP_CRIT(3), SENSORS_W83793_TEMP_CRIT_HYST(3), -1 } },
+  { fmtTemps_1, rrdF1, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(4), SENSORS_W83793_TEMP_CRIT(4), SENSORS_W83793_TEMP_CRIT_HYST(4), -1 } },
+  { fmtTemps_0, rrdF0, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(5), SENSORS_W83793_TEMP_CRIT(5), SENSORS_W83793_TEMP_CRIT_HYST(5), -1 } },
+  { fmtTemps_0, rrdF0, DataType_temperature, 0, 0,
+    { SENSORS_W83793_TEMP(6), SENSORS_W83793_TEMP_CRIT(6), SENSORS_W83793_TEMP_CRIT_HYST(6), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(0), SENSORS_W83793_IN_MIN(0), SENSORS_W83793_IN_MAX(0), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(1), SENSORS_W83793_IN_MIN(1), SENSORS_W83793_IN_MAX(1), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(2), SENSORS_W83793_IN_MIN(2), SENSORS_W83793_IN_MAX(2), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(3), SENSORS_W83793_IN_MIN(3), SENSORS_W83793_IN_MAX(3), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(4), SENSORS_W83793_IN_MIN(4), SENSORS_W83793_IN_MAX(4), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(5), SENSORS_W83793_IN_MIN(5), SENSORS_W83793_IN_MAX(5), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(6), SENSORS_W83793_IN_MIN(6), SENSORS_W83793_IN_MAX(6), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(7), SENSORS_W83793_IN_MIN(7), SENSORS_W83793_IN_MAX(7), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(8), SENSORS_W83793_IN_MIN(8), SENSORS_W83793_IN_MAX(8), -1 } },
+  { fmtVolts_2, rrdF2, DataType_voltage, 0, 0,
+    { SENSORS_W83793_IN(9), SENSORS_W83793_IN_MIN(9), SENSORS_W83793_IN_MAX(9), -1 } },
+  { fmtVolt_3, rrdF3, DataType_voltage, 0, 0,
+    { SENSORS_W83793_VID0, -1 } },
+  { fmtVolt_3, rrdF3, DataType_voltage, 0, 0,
+    { SENSORS_W83793_VID1, -1 } },
+  { NULL }
+};
+
+static const ChipDescriptor w83793_chip = {
+  w83793_names, w83793_features, 0, 0
+};
+
+
 /** ALL **/
 
 const ChipDescriptor * const knownChips[] = {
@@ -1179,6 +1407,7 @@ const ChipDescriptor * const knownChips[] = {
   &lm75_chip,
   &lm78_chip,
   &lm80_chip,
+  &lm87_chip,
   &max1617_chip,
   &maxilife_chip,
   &sis5595_chip,
@@ -1191,7 +1420,11 @@ const ChipDescriptor * const knownChips[] = {
   &it87_chip,
   &asb100_chip,
   &pc87360_chip,
+  &pc87427_chip,
   &w83627ehf_chip,
   &f71805f_chip,
+  &vt1211_chip,
+  &k8temp_chip,
+  &w83793_chip,
   NULL
 };
