@@ -79,8 +79,8 @@ loadConfig
   if (!strcmp (cfgPath, "-")) {
     if (!reload) {
       if ((ret = sensors_init (stdin))) {
-        if (ret == SENSORS_ERR_PROC)
-          sensorLog (LOG_ERR, "Error reading /proc; modules probably not loaded");
+        if (ret == -SENSORS_ERR_PROC)
+          sensorLog (LOG_ERR, "Error reading /proc or /sys; modules probably not loaded");
         else
           sensorLog (LOG_ERR, "Error %d loading sensors configuration file: <stdin>", ret);
         ret = 12;
@@ -96,8 +96,8 @@ loadConfig
       sensorLog (LOG_ERR, "Error opening sensors configuration file: %s", cfgPath);
       ret = 11;
     } else if ((ret = sensors_init (cfg))) {
-      if (ret == SENSORS_ERR_PROC)
-        sensorLog (LOG_ERR, "Error reading /proc; modules probably not loaded");
+      if (ret == -SENSORS_ERR_PROC)
+        sensorLog (LOG_ERR, "Error reading /proc or /sys; modules probably not loaded");
       else
         sensorLog (LOG_ERR, "Error %d loading sensors configuration file: %s", ret, cfgPath);
       ret = 11;
